#
# spec file for package libtorrent-rasterbar
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   libtorrent
%define sover   9
%define _version 1_1_11
%bcond_without  python2
%bcond_without  python3
%bcond_with     examples
%bcond_with     tests
Name:           libtorrent-rasterbar
Version:        1.1.11
Release:        144.3
Summary:        A C++ implementation of the BitTorrent protocol
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://libtorrent.org/
Source:         https://github.com/arvidn/%{_name}/releases/download/%{_name}_%{_version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
%if %{with python2}
BuildRequires:  python-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_random-devel
BuildRequires:  libboost_system-devel
%if %{with python2}
BuildRequires:  libboost_python-devel
%endif
%if %{with python3}
BuildRequires:  libboost_python3-devel
%endif
%else
BuildRequires:  boost-devel >= 1.54
# For quadmath.h we need gcc-fortran on openSUSE Leap 14.x and older.
BuildRequires:  gcc-fortran
%endif

%description
libtorrent-rasterbar is a C++ library that aims to be a good
alternative to all the other bittorrent implementations around.
It is a library and not a full featured client, although it comes
with a working example client.

This package holds the sample client and example files for
libtorrent-rasterbar.

%package -n %{name}%{sover}
Summary:        A C++ implementation of the BitTorrent protocol
Group:          System/Libraries

%description -n %{name}%{sover}
libtorrent-rasterbar is a C++ library that aims to be a good
alternative to all the other bittorrent implementations around.
It is a library and not a full featured client, although it comes
with a working example client.

%if %{with python2}
%if 0%{?suse_version} >= 1500
%package -n python2-%{name}
%else
%package -n python-%{name}
%endif
Summary:        Python Bindings for libtorrent-rasterbar
Group:          Development/Libraries/Python
%if 0%{?suse_version} >= 1500
# python-libtorrent-rasterbar was last used in openSUSE Leap 42.2.
Provides:       python-%{name} = %{version}-%{release}
Obsoletes:      python-%{name} < %{version}-%{release}

%description -n python2-%{name}
%else
Provides:       python2-%{name} = %{version}-%{release}
Obsoletes:      python2-%{name} < %{version}-%{release}

%description -n python-%{name}
%endif
Python Bindings for the libtorrent-rasterbar package.
%endif

%package -n python3-%{name}
Summary:        Python Bindings for libtorrent-rasterbar
Group:          Development/Libraries/Python

%description -n python3-%{name}
Python Bindings for the libtorrent-rasterbar package.

%package tools
Summary:        Example tools from libtorrent-rasterbar
Group:          Development/Libraries/C and C++

%description tools
Example tools from the libtorrent-rasterbar package.

%package devel
Summary:        Header files for libtorrent, a C++ implementation of the BitTorrent protocol
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       gcc-c++
Requires:       pkgconfig(openssl)
%if 0%{?suse_version} >= 1500
Requires:       libboost_headers-devel
%else
Requires:       boost-devel >= 1.54
%endif

%description devel
libtorrent-rasterbar is a C++ library that aims to be a good
alternative to all the other bittorrent implementations around.
It is a library and not a full featured client, although it comes
with a working example client.

This package holds the development files for libtorrent-rasterbar.

%package doc
Summary:        Documentation for libtorrent-rasterbar
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Documentation for the libtorrent-rasterbar package.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
%if 0%{?suse_version} < 1500
export CXXFLAGS="$CXXFLAGS -std=c++11"
%ifarch aarch64
# Some architectures require explicit linkage to libboost_atomic on boost 1.55 and older.
export LIBS="$LIBS -lboost_atomic"
%endif
%endif

%global _configure ../configure
for py in %{?with_python2:python} %{?with_python3:python3}; do
    mkdir -p "build-$py"
    pushd "build-$py"
    export PYTHON="$py"
    %configure \
      --disable-static       \
      --disable-silent-rules \
      --with-libiconv        \
%if %{with tests}
      --enable-tests         \
%endif
%if %{with examples}
      --enable-examples      \
%endif
      --with-boost-python="boost_$py" \
      --enable-python-binding
    make %{?_smp_mflags} V=1
    popd
done

%install
%if %{with python2}
%make_install -C build-python
%endif
%if %{with python3}
%make_install -C build-python3
%endif

find %{buildroot} -type f -name "*.la" -delete -print
# Move doc to a separate package.
mkdir -p %{buildroot}%{_docdir}/%{name}/
cp -r docs/* %{buildroot}%{_docdir}/%{name}/

%if %{with examples}
# Drop tests binaries from the libtorrent-rasterbar-tools subpackage.
rm -v %{buildroot}%{_bindir}/{client_test,connection_tester,enum_if} \
  %{buildroot}%{_bindir}/{fragmentation_test,parse_hash_fails} \
  %{buildroot}%{_bindir}/{parse_request_log,rss_reader,upnp_test,utp_test}
%endif

%if %{with tests}
%check
%if %{with python2}
make check %{?_smp_mflags} V=1 -C build-python
%endif
%if %{with python3}
make check %{?_smp_mflags} V=1 -C build-python3
%endif
%endif

%post -n %{name}%{sover} -p /sbin/ldconfig

%postun -n %{name}%{sover} -p /sbin/ldconfig

%if %{with examples}
%files tools
%{_bindir}/dump_torrent
%{_bindir}/make_torrent
%{_bindir}/simple_client
%endif

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS ChangeLog
%{_libdir}/%{name}.so.%{sover}*

%if %{with python2}
%if 0%{?suse_version} >= 1500
%files -n python2-%{name}
%else
%files -n python-%{name}
%endif
%{python_sitearch}/%{_name}*.so
%{python_sitearch}/python_%{_name}-*
%endif

%if %{with python3}
%files -n python3-%{name}
%{python3_sitearch}/%{_name}*.so
%{python3_sitearch}/python_%{_name}-*
%endif

%files devel
%{_includedir}/%{_name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%doc %{_docdir}/%{name}/

%changelog
* Thu Jan 24 2019 jengelh@inai.de
- Avoid repeating the name in summary.
- Remove future goals from description.
- Remove idempotent %%if..%%endif guards.
* Mon Nov 26 2018 adam.majer@suse.de
- Update to version 1.1.11:
  * Fix move_storage with save_path with a trailing slash
  * Fix tracker announce issue, advertising port 0 in secondary
    IPv6 announce
  * Fix missing boost/noncopyable.hpp includes
  * Fix python binding for torrent_info::creation_date()
- Changes since version 1.1.10:
  * Fix issue in udp_socket with unusual socket failure
  * Split progress_notification alert category into
    file-, piece- and block progress
  * utp close-reason fix
  * Exposed default add_torrent_params flags to python bindings
  * Fix redundant flushes of partfile metadata
  * Add option to ignore min-interval from trackers on
    force-reannounce
  * Raise default setting for active_limit
  * Fall back to copy+remove if rename_file fails
  * Improve handling of filesystems not supporting fallocate()
  * Force-Proxy no longer disables DHT
  * Improve connect-boost feature, to make new torrents quickly
    connect peers
* Fri Sep 14 2018 sor.alexei@meowr.ru
- Update to version 1.1.9:
  * Save both file and piece priorities in the resume file.
  * Add a missing stats_metric python binding.
  * uTP connections are no longer exempt from rate limits by default.
  * Fix exporting files from partfile whilst seeding.
  * Fix an issue when subsequent file priority updates cause the
    torrent to stop.
* Tue Jul  3 2018 sor.alexei@meowr.ru
- Update to version 1.1.8:
  * Fix disc I/O performance of checking hashes and creating
    torrents.
  * Fix a race condition in part_file.
  * Fix part_file open mode compatibility test.
  * Fix a race condition in the random number generator.
  * Fix a race condition in stat_cache (drive storage).
  * Improve error handling of failing to change file priority.
    The API for custom storage implementations was altered.
  * Set the hidden attribute when creating the part file.
  * Fix tracker announces reporting more data downloaded than the
    size of the torrent.
  * Fix a recent regression with the force_proxy setting.
- Remove libtorrent-rasterbar-1.1.7-boost-1.67.patch.
- Re-enable building of the Python 2 module to mirror the boost
  package.
* Sun Jun 17 2018 sor.alexei@meowr.ru
- Disable building of the Python 2 module and conditionalise both
  Python's like in the boost package.
- Rename python2-libtorrent-rasterbar back to
  python-libtorrent-rasterbar on openSUSE Leap 42.3 and older.
* Tue Apr 17 2018 sor.alexei@meowr.ru
- Update to version 1.1.7:
  * Don't perform DNS lookups for the DHT bootstrap unless DHT is
    enabled.
  * Fix an issue where setting file/piece priority would stop
    checking.
  * Expose post_dht_stats() to python bindings.
  * Fix backwards compatibility to downloads without partfiles.
  * Improve part-file related error messages.
  * Fix reporting &redundant= in tracker announces.
  * Fix tie-break in duplicate peer connection disconnect logic.
  * Fix an issue with SSL tracker connections left in CLOSE_WAIT
    state.
  * Defer truncating existing files until the first time we write
    to them.
  * Fix an issue when receiving a torrent with 0-sized padfiles as
    a magnet link.
  * Fix an issue resuming 1.0.x downloads with a file priority 0.
  * Fix torrent_status::next_announce.
  * Fix pad-file scalability issue.
  * Made coalesce_reads/coalesce_writes settings take effect.
  * Use unique peer_ids per connection.
  * Fix tracker connection bind issue for IPv6 trackers.
  * Fix error handling of some merkle torrents.
  * Fix error handling of unsupported hard-links.
- Add libtorrent-rasterbar-1.1.7-boost-1.67.patch: add Boost 1.67+
  support (boo#1089812).
* Thu Jan  4 2018 virtuousfox@gmail.com
- Update to version 1.1.6:
  * Deprecate save_encryption_settings (they are part of the normal settings).
  * Add getters for peer_class_filter and peer_class_type_filter.
  * Make torrent_handler::set_priority() to use peer_classes.
  * Fix support for boost-1.66 (requires C++11).
  * Fix i2p support.
  * Fix loading resume data when in seed mode.
  * Fix part-file creation race condition.
  * Fix issue with initializing settings on session construction.
  * Fix issue with receiving interested before metadata.
  * Fix IPv6 tracker announce issue.
  * Restore path sanitization behavior of ":".
  * Fix listen socket issue when disabling "force_proxy" mode.
  * Fix full allocation failure on APFS.
- Remove fix-build-against-boost-1.66.patch: fixed upstream.
* Sat Dec 30 2017 wbauer@tmo.at
- Add fix-build-against-boost-1.66.patch to fix build with the
  latest boost in Factory
* Sat Oct 21 2017 sor.alexei@meowr.ru
- Update to version 1.1.5:
  * Fix an infinite loop when parsing certain invalid magnet links.
  * Fix parsing torrents with certain invalid filenames.
  * Fix a leak of torrent_peer objecs (entries in peer_list).
  * Fix a leak of peer_class objects (when setting per-torrent rate
    limits).
  * Expose peer_class API to python bindings.
  * Fix integer overflow in whole_pieces_threshold logic.
  * Fix python bindings for torrent_handle, to be hashable.
  * Fix IPv6 tracker support by performing the second announce in
    more cases.
  * Fix utf-8 encoding check in torrent parser.
  * Fix an infinite loop when parsing maliciously crafted
    torrents.
  * Fix an invalid read in parse_int in bdecoder.
  * Fix an issue with very long tracker- and web seed URLs.
  * Do not attempt to create empty files on startup, if they
    already exist.
  * Fix force-recheck issue (new files would not be picked up).
  * Fix an inconsistency in file_priorities and
    override_resume_data behaviour.
  * Fix paused torrents not generating a state update when their
    ul/dl rate transitions to zero.
- Remove boost-1_65-fix.patch: fixed upstream.
* Mon Oct  9 2017 fisiu@opensuse.org
- Update to 1.1.4:
  * Corrected missing const qualifiers on bdecode_node.
  * Fix changing queue position of paused torrents (1.1.3 regression).
  * Fix re-check issue after move_storage.
  * Handle invalid arguments to set_piece_deadline().
  * Move_storage did not work for torrents without metadata.
  * Improve shutdown time by only announcing to trackers whose IP we know.
  * Fix python3 portability issue in python binding.
  * Delay 5 seconds before reconnecting socks5 proxy for UDP ASSOCIATE.
  * Fix NAT-PMP crash when removing a mapping at the wrong time.
  * Improve path sanitization (filter unicode text direction characters).
  * Deprecate partial_piece_info::piece_state.
  * Bind upnp requests to correct local address.
  * Save resume data when removing web seeds.
  * Fix proxying of https connections.
  * Fix race condition in disk I/O storage class.
  * Fix http connection timeout on multi-homed hosts.
  * Removed depdendency on boost::uintptr_t for better compatibility.
  * Fix memory leak in the disk cache.
  * Fix double free in disk cache.
  * Forward declaring libtorrent types is discouraged. a new fwd.hpp header is
    provided.
- Add boost-1_65-fix.patch: fix building with boost 1.65.
- Drop libtorrent-rasterbar-fix-build-boost-1.54.patch.
* Tue May 23 2017 sor.alexei@meowr.ru
- Fix Python3 bindings.
* Sat Apr 22 2017 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * Remove (broken) support for incoming connections over socks5.
  * Restore announce_entry's timestamp fields to posix time in
    python bindings.
  * Deprecate torrent_added_alert (in favour of add_torrent_alert).
  * Fix python bindings for parse_magnet_uri.
  * Fix a minor robustness issue in DHT bootstrap logic.
  * Fix an issue where torrent_status::num_seeds could be negative.
  * Document deprecation of dynamic loading/unloading of torrents.
  * Include user-agent in tracker announces in anonymous_mode for
    private torrents.
  * Add support for IPv6 peers from udp trackers.
  * Correctly URL encode the IPv6 argument to trackers.
  * Fix a bug where settings_pack::file_pool_size setting was not
    being honored.
  * Add a feature to periodically close files (to make windows
    clear disc cache).
  * Fix a bug in torrent_handle::file_status.
  * Fix an issue with peers not updated on metadata from magnet
    links.
- Remove libtorrent-rasterbar-1.1.2-fix-python-timestamp.patch.
* Wed Mar 29 2017 sor.alexei@meowr.ru
- Add libtorrent-rasterbar-1.1.2-fix-python-timestamp.patch:
  Restore announce_entry's timestamp fields to POSIX time in
  Python bindings (commit 852fada, boo#1031510).
* Tue Mar  7 2017 sor.alexei@meowr.ru
- Explicitly require libboost_python3-devel on openSUSE later than
  Leap 42.x.
- Rename python-libtorrent-rasterbar to
  python2-libtorrent-rasterbar to follow Python packaging policies.
* Sat Mar  4 2017 aloisio@gmx.com
- Update to version 1.1.2:
  * Default TOS marking to 0x20.
  * Fix invalid access when leaving seed-mode with outstanding hash
    jobs.
  * Fix an ABI compatibility issue introduced with preformatted
    entry type.
  * Add web_seed_name_lookup_retry to session_settings.
  * Slightly improve proxy settings backwards compatibility.
  * Add a function to get default settings.
  * Updating super seeding would include the torrent in
    state_update_alert.
  * Fix an issue where num_seeds could be greater than num_peers in
    torrent_status.
  * Finished non-seed torrents can also be in super-seeding mode.
  * Fix an issue related to unloading torrents.
  * Fix finished-time calculation.
  * Add missing min_memory_usage() and high_performance_seed()
    settings presets to Python.
  * Fix a stat cache issue that sometimes would produce incorrect
    resume data.
  * Storage optimisation to peer classes.
  * Fix the torrent name in alerts of builds with deprecated
    functions.
  * Make torrent_info::is_valid() return false if a torrent failed
    to load.
  * Fix per-torrent rate limits for >256 peer classes.
  * Don't load user_agent and peer_fingerprint from session_state.
  * Fix the file rename issue with name prefix matching torrent
    name.
  * Fix division by zero when setting tick_interval > 1000.
  * Fix move_storage() to its own directory (would delete the
    files).
  * Fix the socks5 support for UDP.
  * Add a setting urlseed_max_request_bytes to handle large web
    seed requests.
  * Fix Python bindings crash with non-default C++11.
  * Add trackers from the add_torrent_params/magnet links to
    separate tiers.
  * Fix a resumedata check issue with files with priority 0
    (boo#1028448).
  * Deprecate the mmap_cache feature.
  * Add an utility function for generating the peer ID fingerprint.
  * Fix a bug in last-seen-complete.
  * Remove a file size limit in the torrent_info filename
    constructor.
  * Fix tail-padding for the last file in create_torrent.
  * Don't send the user-agent in metadata http downloads or UPnP
    requests when in the anonymous mode.
  * Fix the internal resolve links lookup for mutable torrents.
  * Hint DHT bootstrap nodes of actual bootstrap request.
- Dropped libtorrent-rasterbar-python-cxxflags.patch (accepted
  upstream).
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Dec  5 2016 sor.alexei@meowr.ru
- Require boost 1.54+ instead of 1.61+ again.
- Add libtorrent-rasterbar-fix-build-boost-1.54.patch: Fix
  building with Boost 1.54.
- Add libtorrent-rasterbar-python-cxxflags.patch: Fix Python
  bindings crash with non-default C++11 (boo#1013570).
* Mon Oct 10 2016 fisiu@opensuse.org
- Require boost => 1.61 to fix build failures.
* Sun Aug 28 2016 sor.alexei@meowr.ru
- Update to version 1.1.1:
  * Update puff.c for gzip inflation.
  * Add dht_bootstrap_node a setting in settings_pack (and add
    default).
  * Make pad-file and symlink support conform to BEP47.
  * Fix piece picker bug that could result in division by zero.
  * Fix value of current_tracker when all tracker failed.
  * Deprecate lt_trackers extension.
  * Remove load_asnum_db and load_country_db from python bindings.
  * Fix a crash in session::get_ip_filter when not having set one.
  * Fix filename escaping when repairing torrents with broken web
    seeds.
  * fix a bug where file_completed_alert would not be posted unless
    file_progress had been queries by the client.
  * Move files one-by-one when moving storage for a torrent.
  * Fix bug in python bindings of announce_entry.
  * Fix a bug related to flag_merge_resume_http_seeds flag in
    add_torrent_params.
  * Fixed inverted priority of incoming piece suggestions.
  * Optimise allow-fast logic.
  * Fix an issue where FAST extension messages were not used during
    handshake.
  * Fix a crash on invalid input in http_parser.
  * Upgrade to libtommath 1.0.
  * Fix parsing of an IPv6 endpoint with invalid port character
    separator.
  * Add a limited support for new x.pe parameter from BEP 9.
  * Fix dht stats counters that weren't being updated.
  * Make sure add_torrent_alert is always posted before other
    alerts for the torrent.
  * Fix a peer-class leak when settings per-torrent rate limits.
  * Add a new "preformatted" type to bencode entry variant type.
  * Improve Socks5 support and test coverage.
  * Fix set_settings in python bindings.
  * Add missing alert categories in python bindings.
  * Add dht_get_peers_reply_alert alert in python bindings.
  * Fix updating the node id reported to peers after changing IPs.
- Remove libtorrent-rasterbar-1.1.0-fix-get-ip-filter.patch: merged
  upstream.
- Remove libtorrent-rasterbar-1.1.0-remove-x86-only-flag.patch,
  libtorrent-rasterbar-1.1.0-add_ppc64le_as_64_bit_system_libraries.patch,
  libtorrent-rasterbar-1.1.0-fix-invalid-input-crash.patch,
  libtorrent-rasterbar-1.1.0-python-fixes.patch: fixed upstream.
* Wed Aug 17 2016 sor.alexei@meowr.ru
- Append commit f05fad0 to
  libtorrent-rasterbar-1.1.0-python-fixes.patch from upstream.
- Set boost requirement version to 1.53+ as in commit 633d062.
* Fri Jul 29 2016 normand@linux.vnet.ibm.com
- new libtorrent-rasterbar-1.1.0-add_ppc64le_as_64_bit_system_libraries.patch
  to allow ppc64le build.
  provided upstream https://github.com/arvidn/libtorrent/pull/967
* Sat Jul 23 2016 jengelh@inai.de
- Remove useless duplicate pkgconfig dependency
* Wed Jul 20 2016 sor.alexei@meowr.ru
- Add _constraints, specify 3.5G as a minimal RAM requirement
  (but 2G on arm6l/arm7l): that's somewhat around what is needed
  for the build not to fail.
* Sun Jul 17 2016 sor.alexei@meowr.ru
- Add a bcond to enable tests build (disabled by default).
- Add libtorrent-rasterbar-1.1.0-fix-get-ip-filter.patch: fix Deluge
  crashing when IP filters are used without patching Deluge
  (commit 66e5994) (boo#978600).
- Add libtorrent-rasterbar-1.1.0-python-fixes.patch from upstream:
  fixes for Python bindings (commits e4fd45e, 80710ab, f01ac8f,
  42c6376) (boo#988986).
* Sun Jul  3 2016 sor.alexei@meowr.ru
- Remove "-lrt" link hack.
- Don't force C++11 on openSUSE newer than Leap 42.x.
* Wed Jun 29 2016 sor.alexei@meowr.ru
- Disable Python3 support for openSUSE Leap 42.x after all.
* Tue Jun 21 2016 aloisio@gmx.com
- Added explicit linking of libboost_devel for aarch64, see
  https://svn.boost.org/trac/boost/ticket/9041
* Mon Jun 20 2016 aloisio@gmx.com
- Updated version requirement for boost-devel
  and added -std=c++11 in CXXFLAGS to address
  a build problem with qbittorrent 3.3.5
* Mon Jun  6 2016 sor.alexei@meowr.ru
- Add libtorrent-rasterbar-1.1.0-fix-invalid-input-crash.patch: fix
  crash on invalid input in http_parser (commit 3624ce6, boo#983228).
* Mon May 16 2016 sor.alexei@meowr.ru
- Build Python3 bindings for openSUSE Leap 42.2 and newer.
- Remove GeoIP support remnants, was removed in 1.1.0.
- Replace fix-sse-only-on-x86.patch with
  libtorrent-rasterbar-1.1.0-remove-x86-only-flag.patch
  (commit 680eddf) and apply unconditionally.
* Fri Apr 15 2016 rpm@fthiessen.de
- Added fix-sse-only-on-x86.patch to fix build on
  non x86 architectures.
* Thu Apr 14 2016 rpm@fthiessen.de
- Update to 1.1.0:
  * fix duplicate ACK issue in uTP
  * experimental support for BEP 38, "mutable torrents"
  * replaced lazy_bdecode with a new bdecoder that's a lot more efficient
  * General speed improvements.
  * support SSL over uTP connections
  * Removed built-in GeoIP support (this functionality is orthogonal to libtorrent)
  * General better multithreading support.
  * Added support for hashing pieces in multiple threads
  * Fix division by zero in super-seeding logic
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 1.0.9:
  * Fix issue in checking outgoing interfaces (when that option is
    enabled).
  * Python binding fix for boost-1.60.0.
  * Improve reliability of binding listen sockets.
  * Support SNI in https web seeds and trackers.
  * Fix unhandled exception in DHT when receiving a DHT packet over
    IPv6.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 1.0.8:
  * Fix web seed request size.
  * Fix bug where web seeds were not used for torrents added by URL.
  * Fix long filename issue.
  * Fix performance bug in DHT torrent eviction.
  * Fix bug when deleting files for magnet links before they had
    metadata.
- Remove libtorrent-rasterbar-boost-1.60.patch: fixed upstream.
* Thu Jan 14 2016 sor.alexei@meowr.ru
- Add libtorrent-rasterbar-boost-1.60.patch: register_ptr_to_python
  for boost::shared_ptr<alert> (by Andrew Resch).
* Mon Nov 23 2015 p.drouand@gmail.com
- Update to version 1.0.7
  * fix bug where loading settings via load_state() would not trigger all
    appropriate actions
  * fix bug where 32 bit builds could use more disk cache than the virtual
    address space (when set to automatic)
  * fix support for torrents with > 500'000 pieces
  * fix ip filter bug when banning peers
  * fix IPv6 IP address resolution in URLs
  * introduce run-time check for torrent info-sections beeing too large
  * fix web seed bug when using proxy and proxy-peer-connections=false
  * fix bug in magnet link parser
  * introduce add_torrent_params flags to merge web seeds with resume data
    (similar to trackers)
  * fix bug where dont_count_slow_torrents could not be disabled
  * fix fallocate hack on linux (fixes corruption on some architectures)
  * fix auto-manage bug with announce to tracker/lsd/dht limits
  * improve DHT routing table to not create an unbalanced tree
  * fix bug in uTP that would cause any connection taking more than one second
    to connect be timed out (introduced in the vulnerability path)
  * fixed falling back to sending UDP packets direct when socks proxy fails
  * fixed total_wanted bug (when setting file priorities in add_torrent_params)
  * fix python3 compatibility with sha1_hash
* Sun Aug  2 2015 sor.alexei@meowr.ru
- Update to 1.0.6:
  * Fix µTP vulnerability.
  * Make UTF-8 conversions more lenient.
  * Fix loading of piece priorities from resume data.
  * Improve seed-mode handling (seed-mode will now automatically be
    left when performing operations implying it's not a seed).
  * Fix issue with file priorities and override resume data.
  * Fix request queue size performance issue.
  * Slightly improve UDP tracker performance.
  * Fix HTTP scrapes.
  * Add missing port mapping functions to Python binding.
  * Fix bound-checking issue in bdecoder.
  * Expose missing dht_settings fields to Python.
  * Add function to query the DHT settings.
  * Fix bug in 'dont_count_slow_torrents' feature, which would
    start too many torrents.
* Mon Jun  8 2015 mvyskocil@opensuse.org
- Change Group of shlib to System/Libraries
* Fri May 29 2015 sor.alexei@meowr.ru
- Update to 1.0.5:
  * Improve ip_voter to avoid flapping.
  * Fix bug when max_peerlist_size was set to 0.
  * Fix issues with missing exported symbols when building dll.
  * Fix division by zero bug in edge case while connecting peers.
- Spec cleanup.
* Mon Apr  6 2015 fisiu@opensuse.org
- Update to 1.0.4:
  * so many changes since last package version, all of them can be found in
    ChangeLog file.
  * Bump so version to 8.
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.16.19
  * python binding build fix for boost-1.57.0
  * add --enable-export-all option to configure script, to export
    all symbols from libtorrent
  * python bindings fixes
  * handle overlong utf-8 sequences
  * fix bug in error handling in protocol encryption
- Remove obsolete conditional macros
* Tue Jul  1 2014 fisiu@opensuse.org
- Update to 0.16.17:
  * don't fall back on wildcard port in UPnP
  * fix local service discovery for magnet links
  * fix bitfield issue in file_storage
  * added work-around for MingW issue in file I/O
  * fixed sparse file detection on windows
  * fixed bug in gunzip
  * fix to use proxy settings when adding .torrent file from URL
  * fix resume file issue related to daylight savings time on windows
  * improve error checking in lazy_bdecode
* Sat Mar 29 2014 fisiu@opensuse.org
- Update to 0.16.16 (changes since 0.16.12):
  * add missing add_files overload to the python bindings
  * improve error handling in http gunzip
  * fix debug logging for banning web seeds
  * improve support for de-selected files in full allocation mode
  * fix dht_bootstrap_alert being posted
  * SetFileValidData fix on windows (prevents zero-fill)
  * fix minor lock_files issue on unix
  * fix mingw time_t 64 bit issue
  * fix use of SetFileValidData on windows
  * fix crash when using full allocation storage mode
  * improve error_code and error_category support in python bindings
  * fix python binding for external_ip_alert
  * make lt_tex more robust against bugs and malicious behavior
  * HTTP chunked encoding fix
  * expose file_granularity flag to python bindings
  * fix DHT memory error
  * change semantics of storage allocation to allocate on first write rather
    than on startup (behaves better with changing file priorities)
  * fix resend logic in response to uTP SACK messages
  * only act on uTP RST packets with correct ack_nr
  * make uTP errors log in normal log mode (not require verbose)
  * deduplicate web seed entries from torrent files
  * improve error reporting from lazy_decode()
  * fix auto-manage issue when pausing session
  * fix bug in non-sparse mode on windows, causing incorrect file errors to
    be generated
  * fix set_name() on file_storage actually affecting save paths
  * fix large file support issue on mingw
  * add some error handling to set_piece_hashes()
  * fix completed-on timestamp to not be clobbered on each startup
  * fix deadlock caused by some UDP tracker failures
  * fix potential integer overflow issue in timers on windows
  * minor fix to peer_proportional mixed_mode algorithm (TCP limit could go
    too low)
  * graceful pause fix
  * i2p fixes
  * fix issue when loading certain malformed .torrent files
  * pass along host header with http proxy requests and possible
    http_connection shutdown hang
* Thu Dec 12 2013 fisiu@opensuse.org
- Strip down content of -tools subpackage to the most useful tools.
* Tue Nov 12 2013 fisiu@opensuse.org
- Update to 0.16.12:
  * fix building with C++11
  * fix IPv6 support in UDP socket (uTP)
  * increase max allowed outstanding piece requests from peers
  * uTP performance improvement. only fast retransmit one packet at a time
  * improve error message for 'file too short'
  * fix piece-picker stat bug when only selecting some files for download
  * fix bug in async_add_torrent when settings file_priorities
  * fix boost-1.42 support for python bindings
* Mon Sep 16 2013 fisiu@opensuse.org
- Update to 0.16.11:
  * fix web seed URL double escape issue
  * fix string encoding issue in alert messages
  * fix SSL authentication issue
  * deprecate std::wstring overloads. long live utf-8
  * improve time-critical pieces feature (streaming)
  * introduce bandwidth exhaustion attack-mitigation in allowed-fast pieces
  * python binding fix issue where torrent_info objects where
    destructing when their torrents were deleted
  * added missing field to scrape_failed_alert in python bindings
  * GCC 4.8 fix
  * fix proxy failure semantics with regards to anonymous mode
  * fix round-robin seed-unchoke algorithm
  * add bootstrap.sh to generage configure script and run configure
  * fix bug in SOCK5 UDP support
  * fix issue where torrents added by URL would not be started immediately
* Tue Jun  4 2013 fisiu@opensuse.org
- Update to 0.16.10:
  * fix encryption level handle invalid values
  * add a number of missing functions to the python binding
  * fix typo in Jamfile for building shared libraries
  * prevent tracker exchange for magnet links before metadata is
    received
  * fix crash in make_magnet_uri when generating links longer than
    1024 characters
  * fix hanging issue when closing files on windows (completing a
    download)
  * fix piece picking edge case that could cause torrents to get
    stuck at hash failure
  * try unencrypted connections first, and fall back to encryption
    if it fails (performance improvement)
  * add missing functions to python binding (flush_cache(),
    remap_files() and orig_files())
  * improve handling of filenames that are invalid on windows
  * support 'implied_port' in DHT announce_peer
  * don't use pool allocator for disk blocks (cache may now return
    pages to the kernel)
* Thu Apr 25 2013 mhrusecky@suse.cz
- update to 0.16.9:
  * fix long filename truncation on windows
  * distinguish file open mode when checking files and downloading/seeding with bittorrent.
    updates storage interface
  * improve file_storage::map_file when dealing with invalid input
  * improve handling of invalid utf-8 sequences in strings in torrent files
  * handle more cases of broken .torrent files
  * fix bug filename collision resolver
  * fix bug in filename utf-8 verification
  * make need_save_resume() a bit more robust
  * fixed sparse flag manipulation on windows
  * fixed streaming piece picking issue
- do not hide symbols (drop -fvisibility=hidden) to fix qbittorrent
* Thu Feb 21 2013 lars@linux-schulserver.de
- update to 0.16.8:
  + support torrents with more than 262000 pieces
  + make tracker back-off configurable
  + improve SSL torrent support by using SNI and a single SSL listen socket
  + improved peer exchange performance by sharing incoming
    connections which advertize listen port
  + add web seed support for torrents with pad files
  + introduced a more scalable API for torrent status updates
  + updated the API to add_torrent_params turning all bools into
    flags of a flags field
  + added async_add_torrent() function to significantly improve
    performance when adding many torrents
  + deprecated compact storage allocation
  + feature to encrypt peer connections with a secret AES-256 key
    stored in .torrent file
  + added support for fadvise/F_RDADVISE for improved disk
    read performance
- removed libtorrent-rasterbar-boost-time_utc.patch
- removed libtorrent-rasterbar-0.15.9-missing-return.patch
- specfile cleanup: remove tags and allow to build on SLE-11-SP2
* Fri Aug  3 2012 aj@suse.de
- Fix build with updated boost
* Tue Mar 27 2012 fisiu@opensuse.org
- Upstream update to 0.15.10, bugfix release:
  + fixed peer_tos (type of service) setting
  + fix connection queue issue causing shutdown delays
  + fix overflow bug in progress_ppm field
  + don't filter local peers received from a non-local tracker
  + fix python deadlock when using python extensions
  + fixed small memory leak in DHT
* Wed Jan 25 2012 crrodriguez@opensuse.org
- Usage of symbols visibility is supported but needs either
  using cmake or passing the relevant CXXFLAGS.
* Thu Jan 19 2012 fisiu@opensuse.org
- Upstream update to 0.15.9, bugfix release.
* Fri Dec  9 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Oct 18 2011 fisiu@opensuse.org
- Upstream update to 0.15.8, bugfix release.
- Reworked missing-return patch.
* Sun Oct 16 2011 coolo@suse.com
- fix build for factory
* Tue Jun  7 2011 mrueckert@suse.de
- added back the support to build the examples. they are very
  useful for debugging. they are guarded by a %%bcond_with so they
  wont be build by default.
- disable silent rules to make the check_gcc_output scripts work
* Fri Jun  3 2011 fisiu@opensuse.org
- Disable building examples.
* Sun Apr 10 2011 fisiu@opensuse.org
- Upstream update to 0.15.6, bugfix release.
* Fri Apr  8 2011 fisiu@opensuse.org
- spec cleanup
* Mon Jan 10 2011 fisiu@opensuse.org
- Upstream update to 0.15.5
* Sat Oct  9 2010 fisiu@opensuse.org
- upstream update to 0.15.4
* Sun Apr  4 2010 fisiu@opensuse.org
- revert to version 0.14.10 due to other bugs with current glibc
* Sat Apr  3 2010 fisiu@opensuse.org
- fixed issues with glibc, use posix_memalign() instead of valloc()
* Tue Mar 23 2010 fisiu@opensuse.org
- upstream update to 0.15.0
- cleaned up spec file
- enabled python bindings
- soname gets 6
* Mon Jan 11 2010 fisiu@opensuse.org
- upstream update to 0.14.8
* Tue Nov 24 2009 fisiu82@gmail.com
- upstream update to 0.14.7
* Thu Oct 22 2009 fisiu82@gmail.com
- upstream update to 0.14.6
* Tue Jun  9 2009 fisiu82@gmail.com
- upstream update to 0.14.4
* Tue Apr 28 2009 fisiu82@gmail.com
- upstream update to 0.14.3
* Mon Mar  9 2009 fisiu82@gmail.com
- upstream update to 0.14.2
* Mon Dec 22 2008 fisiu82@gmail.com
- 0.14.1
* Tue Jul 22 2008 fisiu82@gmail.com
- update package to 0.13.1
* Sat May  3 2008 marekstopka@gmail.com
- new package created, based on spec from home:darix obs project
